..
      Copyright 2014-2015 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

=========================================
Welcome to Kolla-Ansible's documentation!
=========================================

Kolla's mission is to provide production-ready containers and deployment tools
for operating OpenStack clouds.

Kolla-Ansible is highly opinionated out of the box, but allows for complete
customization. This permits operators with minimal experience to deploy
OpenStack quickly and as experience grows modify the OpenStack configuration to
suit the operator's exact requirements.

Related Projects
================

This documentation is for Kolla Ansible.

For information on building container images for use with Kolla-Ansible, please
refer to the `Kolla image documentation
<https://docs.openstack.org/kolla/latest/>`_.

`Kayobe <https://kayobe.readthedocs.io>`__ is a related unofficial project that
uses Kolla Ansible and Bifrost to deploy an OpenStack control plane to bare
metal.

Site Notes
==========

This documentation is continually updated and may not represent the state of
the project at any specific prior release. To access documentation for a
previous release of kolla, append the OpenStack release name to the URL. For
example, to access Kolla Ansible documentation for the Stein release:
https://docs.openstack.org/kolla-ansible/stein

Administrator Guide
===================

.. toctree::
   :maxdepth: 2

   admin/index

User Guide
==========

.. toctree::
   :maxdepth: 2

   user/index

Reference
=========

.. toctree::
   :maxdepth: 2

   reference/index

Contributor Guide
=================

.. toctree::
   :maxdepth: 2

   contributor/index
